=================================
The gocept.loginuser distribution
=================================

.. image:: https://github.com/gocept/gocept.loginuser/workflows/tests/badge.svg
    :target: https://github.com/gocept/gocept.loginuser/actions?query=workflow%3Atests
.. image:: https://coveralls.io/repos/github/gocept/gocept.loginuser/badge.svg
    :target: https://coveralls.io/github/gocept/gocept.loginuser

Sqlalchemy user object and password management.

This package is compatible with Python version 3.6 up to 3.9 and PyPy3.
